@@ -123,7 +123,7 @@ def flat_map(
             )
         )
 
-    stage_ = to_stage(stage)
+    stage_ = to_stage(stage, maxsize=maxsize)
 
     return Stage(
         process_fn=FlatMap(f),
