@@ -109,7 +109,7 @@ def map(
             )
         )
 
-    stage_ = to_stage(stage)
+    stage_ = to_stage(stage, maxsize=maxsize)
 
     return Stage(
         process_fn=Map(f),
