@@ -4,9 +4,9 @@ import typing as tp
 from pypeln.utils import A
 
 
-def to_stage(obj: tp.Union[Stage[A], tp.Iterable[A]]) -> Stage[A]:
+def to_stage(obj: tp.Union[Stage[A], tp.Iterable[A]], maxsize: int) -> Stage[A]:
 
     if isinstance(obj, Stage):
         return obj
     else:
-        return from_iterable(obj)
+        return from_iterable(obj, maxsize=maxsize)
