@@ -1,3 +1,4 @@
+import sys
 import typing as tp
 from unittest import TestCase
 
@@ -6,12 +7,12 @@ import hypothesis as hp
 from hypothesis import strategies as st
 
 import pypeln as pl
-from pypeln.task.utils import run_test_async
 
 MAX_EXAMPLES = 10
 T = tp.TypeVar("T")
 
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 def test_from_to_iterable(nums: tp.List[int]):
@@ -30,10 +31,9 @@ def test_from_to_iterable(nums: tp.List[int]):
 
     assert nums_py == nums_pl
 
-
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
-@run_test_async
+@pl.task.utils.run_test_async
 async def test_from_to_iterable_2(nums: tp.List[int]):
 
     nums_pl = nums
