@@ -128,7 +128,7 @@ def flat_map(
             )
         )
 
-    stage = to_stage(stage)
+    stage = to_stage(stage, maxsize=maxsize)
 
     return Stage(
         process_fn=FlatMap(f),
